/* 
 * enPathia
 * Eneso Tecnología de Adaptación, S.L. 
 */

#ifndef __PROFILE_H__
#define __PROFILE_H__

#define MAX_SHORTCUTS					12
#define SHORTCUT_TITLE_MAX_LENGTH		20
#define SHORTCUT_URI_MAX_LENGTH			200

enum
{
	LANG_EN = 0,
	LANG_EL,
	LANG_ES,
	LANG_HE,
	LANG_DE,
	LANG_IT,
	LANG_PT,
	LANG_FR,	
	N_LANGUAGES
};

enum
{
	KEYB_LAYOUT_EN_US = 0,
	KEYB_LAYOUT_EN_UK,
	KEYB_LAYOUT_EL,
	KEYB_LAYOUT_ES,
	KEYB_LAYOUT_HE,
	KEYB_LAYOUT_DE,
	KEYB_LAYOUT_IT,
	KEYB_LAYOUT_PT,
	KEYB_LAYOUT_FR,	
	N_KEYB_LAYOUTS
};

extern gint		current_language;
extern gchar*	language_name [N_LANGUAGES];

extern gint		current_keyb_layout;
extern gchar*	keyb_layout_name [N_KEYB_LAYOUTS];
extern gchar*	keyb_layout_print_name [N_KEYB_LAYOUTS];
extern gchar*	keyb_dictionary_name [N_KEYB_LAYOUTS];

typedef struct
{
	struct
	{
		/* Movement */
		gint		movement_speed;
		gboolean	auto_calibrate;

		/* Stopped time */
		gint		menu_time;
		gint		keyb_time;

		/* Switches */
		gboolean	use_switches;
		gint		switch_action [4];
		gint		long_press_time;

		/* Sensitivity */
		gint		sensitivity [4];
	
		/* Appearance */
		gint		menu_size;
		gboolean	menu_use_images;

		gint		keyb_size;
		gboolean	keyb_show_dictionary;
		gboolean	keyb_show_layout_bar;

		/* Menu disabling */
		gboolean	can_disable_menu;

		/* Auto click */
		gboolean	auto_click;
	}
	config;
	
	/* Main window */
	struct
	{
		gboolean	show;
		gint		x;
		gint		y;
		gint		width;
		gint		height;

		gint		n_shortcuts;
		gchar		shortcut_title [MAX_SHORTCUTS][SHORTCUT_TITLE_MAX_LENGTH + 1];
		gchar		shortcut_uri [MAX_SHORTCUTS][SHORTCUT_URI_MAX_LENGTH + 1];
	}
	main_window;

	/* Keyboard */
	struct
	{
		gint		x;
		gint		y;
	}
	keyboard;

	/* Calibration matrix */
	struct
	{
		gint		matrix [2][3];
	}
	calibration;
}
Profile;

extern Profile 	current_profile;
extern gchar 	current_profile_name [50];

void
load_config_file			(void);
void
update_config_file			(void);

gint
load_profile 				(gchar* name);
gint
save_current_profile 		(void);
void
create_profile 				(gchar* name);
void
remove_profile 				(gchar* name);
void
rename_profile	 			(gchar* name, gchar* new_name);
void
export_profile				(gchar* name, gchar* path);
gboolean
profile_exists 				(gchar* name);

void
send_cfg_speed	 		(void);
void
send_cfg_time 			(void);
void
send_cfg_switches 		(void);
void
send_cfg_sensitivity	(void);
void
send_cfg_calibration	(void);

#endif /* __PROFILE_H__ */
